@@ -14,11 +14,15 @@
 # s <- regressionMetrics(tr,ps,stats=c('mse','mae'))
 #
 regressionMetrics <- function(trues,preds,
-                      stats="mse",
-                      train.y=NULL)
+                              stats=NULL,
+                              train.y=NULL)
 {
+    ## Checking preds
+    if (!is.null(dim(preds))) stop("regressionMetrics:: expecting a vector as predictions.")
+
+    ## Cheking the statistics
     knownMetrics <- c('mae','mse','rmse','mape','nmse','nmae','theil')
-    if (identical(stats,"all"))
+    if (is.null(stats))  # user wants all available stats
         stats <- if (is.null(train.y)) setdiff(knownMetrics,c("nmse","nmae")) else knownMetrics
     
     if (any(c('nmse','nmad') %in% stats) && is.null(train.y))
@@ -26,6 +30,16 @@ regressionMetrics <- function(trues,preds,
     if (!all(stats %in% knownMetrics))
         stop("regressionMetrics:: don't know how to calculate -> ",call.=FALSE,
              paste(stats[which(!(stats %in% knownMetrics))],collapse=','))
+
+    ## copying with missing predictions
+    if (length(preds) != length(trues)) {
+        warning("regressionMetrics:: less predictions than test cases, filling with NAs.")
+        t <- trues
+        t[] <- NA
+        t[names(preds)] <- preds
+        preds <- t
+    }
+   
     N <- length(trues)
     sae <- sum(abs(trues-preds))
     sse <- sum((trues-preds)^2)
@@ -47,7 +61,7 @@ regressionMetrics <- function(trues,preds,
 # s <- classificationMetrics(tr,ps,benMtrx=matrix(c(2,-13,-4,5),2,2))
 #
 classificationMetrics <- function(trues,preds,
-                 stats="err",
+                 stats=NULL,
                  benMtrx=NULL,
                  allCls=unique(c(levels(as.factor(trues)),levels(as.factor(preds)))),
                  posClass=allCls[1],
@@ -55,12 +69,16 @@ classificationMetrics <- function(trues,preds,
                  )
 
 {
+    ## Checking preds
+    if (!is.null(dim(preds))) stop("classificationMetrics:: expecting a vector as predictions.")
+
+    ## Cheking the statistics
     twoClsMetrics <- c('fpr','fnr','tpr','tnr','rec','sens','spec',
                        'prec','rpp','lift','F')
     knownMetrics <- c(twoClsMetrics,c('acc','err','totU',
                       'microF','macroF',"macroRec","macroPrec"))
 
-    if (identical(stats,"all")) {
+    if (is.null(stats)) {
         stats <- knownMetrics
         if (length(allCls) > 2) stats <- setdiff(stats,twoClsMetrics)
         if (is.null(benMtrx))   stats <- setdiff(stats,'totU')
@@ -77,6 +95,15 @@ classificationMetrics <- function(trues,preds,
     r <- rep(NA,length(knownMetrics))
     names(r) <- knownMetrics
 
+    ## copying with missing predictions (only necessary for non-standard WFs)
+    if (length(preds) != length(trues)) {
+        warning("classificationMetrics:: less predictions than test cases, filling with NAs.")
+        t <- trues
+        t[] <- NA
+        t[names(preds)] <- preds
+        preds <- t
+    }
+
     ## copying with eventually missing class labels
     preds <- factor(preds,levels=allCls)
     trues <- factor(trues,levels=allCls)
